<?php
/*
Plugin Name: Add Post URL
Plugin URI: http://easwy.com/blog/wordpress/wp-posturl/
Description: This plugin allows you to insert a user specific text at the beginning/ending of all your post.
Version: 1.0
Author: Easwy Yang
Author URI: http://easwy.com/
*/

/*  Copyright 2009  Easwy Yang  (Homepage: http://easwy.com/)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/


### Create Text Domain For Translations
add_action('init', 'posturl_textdomain');
function posturl_textdomain() {
    $plugin_dir = basename(dirname(__FILE__));
    load_plugin_textdomain( 'wp-posturl', 'wp-content/plugins/' . $plugin_dir, $plugin_dir );
    //load_plugin_textdomain('wp-posturl', false, 'wp-posturl');
}


### Function: Post URL Option Menu
add_action('admin_menu', 'posturl_menu');
function posturl_menu() {
    $plugin_dir = basename(dirname(__FILE__));
    if (function_exists('add_options_page')) {
        add_options_page(__('Add Post URL', 'wp-posturl'),
            __('Add Post URL', 'wp-posturl'), 'manage_options',
            $plugin_dir . '/posturl-options.php') ;
    }
}

### Function: Post URL: Add Post URL for Post
add_action('the_content', 'wp_posturl');
function wp_posturl($text) {
    if (is_single()) {
        // replace macros
        $posturl_options = get_option('posturl_options');
        $post_url_str = $posturl_options['post_url_text'];
        $post_url_str = str_replace("%site_url%", site_url('/'), $post_url_str);
        $post_url_str = str_replace("%site_name%", get_bloginfo('sitename'), $post_url_str);
        $post_url_str = str_replace("%post_url%", get_permalink(), $post_url_str);
        $post_url_str = str_replace("%post_title%", the_title('', '', false), $post_url_str);
        $post_url_str = stripslashes($post_url_str);

        // add to beginning?
	$add_to_beginning = $posturl_options["add_to_beginning"];
        if ($add_to_beginning == 'Yes') {
            $text = $post_url_str.$text;
        }
        else {
            $text .= $post_url_str;
        }

        // add credit?
	$add_credit = $posturl_options["add_credit"];
	if ($add_credit != 'No') {
            $text .= __('<p style="color: #B4B4B4; font-size: -3; font-style: italic">Post Footer automatically generated by <a href="http://easwy.com/blog/wordpress/wp-posturl/" style="color: #AAAAFF; text-decoration: underline;">wp-posturl plugin</a> for wordpress.</p>');
        }
    }
    return $text;
}

### Function: Post URL Options
#add_action('activate_wp-posturl/wp-posturl.php', 'posturl_init');
add_action('activate_' . basename(dirname(__FILE__)) . '/wp-posturl.php', 'posturl_init');
function posturl_init() {
    posturl_textdomain();
    // Add Options
    $posturl_options = array();
    $posturl_options['post_url_text'] = addslashes(__('<div style="font-style: italic"><p><strong>From</strong> <a href="%site_url%">%site_name%</a>, <strong>post</strong> <a href="%post_url%">%post_title%</a></p></div>','wp-posturl'));
    $posturl_options['add_credit'] = 'Yes';
    $posturl_options['add_to_beginning'] = 'No';
    add_option('posturl_options', $posturl_options, 'Post URL Options');
}
?>
